@@ -1,16 +1,16 @@
-import contextily as ctx
 def search(name=None, source=None, id_No=None, markdown=False):
     """
-    Main search function for querying the Global Lake Level Database
-    :param name: Name of Lake or Reservoir. Be sure to use proper spelling. Wildcards (%) are allowed,
-    as is any MySQL 5.7 syntax
-    :type name: str
-    :param source: Lake water level source flag, accepted values are "usgs", "grealm", or "hydroweb"
-    :type source: str
-    :param id_No: Global Lake Level Database identification number,
-    :type id_No: str or int
-    :return: Lake() object
+    Search function that interacts directly with the Global Lake Level Database API.
+    Arguments:
+        name (str): Name of Lake or Reservoir. Be sure to use proper spelling. Wildcards (%) are allowed,as is any MySQL 5.7 syntax
+        source (str): Lake water level source flag, accepted values are "usgs", "grealm", or "hydroweb"
+        id_No (str,int): Global Lake Level Database identification number
+        markdown (bool, optional): Returns markdown dataframe when True
+
+    Returns:
+        Lake object: `Lake()` object
     """
+
     import pandas as pd
     import requests
     import warnings
@@ -65,11 +65,15 @@ def search(name=None, source=None, id_No=None, markdown=False):
 
 def _lake_meta_constructor(df):
     """
-    This function populates the Lake() object with metadata
-    :param df: Pandas DataFrame of lake metadata from search()
-    :type df: Pandas DataFrame
-    :return: Lake() object with associated metadata
+
+    Arguments:
+        df (): Pandas DataFrame of lake metadata from :function:`search`
+
+    Returns:
+        {:class:`Lake`}
+
     """
+
     import pandas as pd
     import requests
     # todo location!!!!!!!!
@@ -86,7 +90,7 @@ def _lake_meta_constructor(df):
             id_No = df.id_No[0]
             observation_period = df['Satellite Observation Period'][0]
             misc_data = {'Type': df.Type[0], 'Resolution': df.Resolution[0]}
-            dataframe = df
+            metadata = df
             lake = Lake(name = name,
                         country = country,
                         continent = continent,
@@ -97,7 +101,7 @@ def _lake_meta_constructor(df):
                         latitude = None,
                         longitude = None,
                         misc_data = misc_data,
-                        dataframe = dataframe,
+                        metadata = metadata,
                         data = None)
             lake.data = _get_levels(lake)
             return lake
@@ -111,7 +115,7 @@ def _lake_meta_constructor(df):
             latitude = df.latitude[0]
             longitude = df.longitude[0]
             misc_data = {'basin': df.basin[0], 'status': df.status[0]}
-            dataframe = df
+            metadata = df
 
             lake = Lake(name = name,
                         country = country,
@@ -123,7 +127,7 @@ def _lake_meta_constructor(df):
                         latitude = latitude,
                         longitude = longitude,
                         misc_data = misc_data,
-                        dataframe = dataframe,
+                        metadata = metadata,
                         data = None)
             lake.data = _get_levels(lake)
             return lake
@@ -145,7 +149,7 @@ def _lake_meta_constructor(df):
             misc_data = df_misc.to_dict(orient = 'list')
             for k in misc_data:
                 misc_data[k] = misc_data[k][0]
-            dataframe = df
+            metadata = df
             lake = Lake(name = name,
                         country = country,
                         continent = continent,
@@ -156,7 +160,7 @@ def _lake_meta_constructor(df):
                         latitude = latitude,
                         longitude = longitude,
                         misc_data = misc_data,
-                        dataframe = dataframe,
+                        metadata = metadata,
                         data = None)
             lake.data = _get_levels(lake)
             return lake
@@ -165,9 +169,12 @@ def _lake_meta_constructor(df):
 def _get_levels(lake):
     """
     This function populates the Lake().data attribute with all available lake levels
-    :param lake: must be of Lake() object with metadata built from _lake_meta_constructor
-    :type lake: class Lake()
-    :return:
+    Arguments:
+        lake(object): must be :class:`Lake` with metadata built from :function:`_lake_meta_constructor`
+
+    Returns:
+        Pandas DataFrame
+
     """
     import requests
     import pandas as pd
@@ -181,38 +188,24 @@ def _get_levels(lake):
 
 
 class Lake(object):
-    """
-
-    """
 
     def __init__(self, name, country, continent, source, original_id, id_No,
-                 observation_period, latitude, longitude, misc_data, dataframe, data):
+                 observation_period, latitude, longitude, misc_data, metadata, data):
         """
-        Lake() constructor
-        :param name: Lake name
-        :type name: str
-        :param country: Country of lake residence
-        :type country: str
-        :param continent: Continent of lake residence
-        :type continent: str
-        :param source: Original database of lake data
-        :type source: str
-        :param original_id: Original identifier of lake
-        :type original_id: str
-        :param id_No: GLLD identification number
-        :type id_No: int
-        :param observation_period: Range of water level data
-        :type observation_period: str
-        :param latitude: Decimal degree latitude
-        :type latitude: str
-        :param longitude: Decimal degree longitude
-        :type longitude: str
-        :param misc_data: Database-specific metadata
-        :type misc_data: dict
-        :param dataframe: Lake metadata as Pandas DataFrame
-        :type dataframe: pandas.DataFrame()
-        :param data: Lake water level timeseries data
-        :type data: pandas.DataFrame()
+        Lake object with associated lake attributes and plotting methods
+        Arguments:
+            name (str): Lake name
+            country (str): Country of lake residence
+            continent (str): Continent of lake residence
+            source (str): Original database of lake data
+            original_id (str): Identifier within original lake database
+            id_No (str): Global Lake Level Database identification number
+            observation_period (str): Date range of accessible water level data
+            latitude (str): Decimal degree latitutde
+            longitude (str): Decimal degree longitude
+            misc_data (dict): Database-specific metadata
+            metadata (DataFrame): Lake metadata as Pandas DataFrame
+            data (DataFrame): Lake water level time-series data
         """
         self.name = name
         self.country = country
@@ -224,29 +217,32 @@ class Lake(object):
         self.latitude = latitude
         self.longitude = longitude
         self.misc_data = misc_data
-        self.dataframe = dataframe
+        self.metadata = metadata
         self.data = data
 
+
     def plot_mapview(self, show=True, out_path=None, zoom=None, provider=None, return_gdf=False, *args, **kwargs):
         """
-        Plot map-style overview of lake location using geopandas as contextily
-        :param show: Flag to determine whether matplotlib.pyplot.show() is called (True) or axis object is returned (
-        False)
-        :type show: bool
-        :param out_path: If supplied, figure will be saved to local filepath
-        :type out_path: str
-        :param zoom: contextily zoom level
-        :type zoom: int
-        :param provider: contextily provider passed as ctx.providers.{your provider here}. See contextily documentation.
-        :param args: additonal *args to pass to matplotlib.pyplot axis
-        :param kwargs: additonal **kwargs to pass to matplotlib.pyplot axis
-        :return: matplotlib axis instance if :param show is False
+        Plot map-style overview of lake location using [geopandas]() and [contextily]()
+        Arguments:
+            show (bool): Flag to determine whether matplotlib.pyplot.show() is called (True) or axis object is
+            returned (False)
+            out_path (str): If supplied, figure will be saved to input filepath
+            zoom (int): contextily zoom level
+            provider ():
+            return_gdf (bool): Returns GeoDataFrame if True
+            *args: Variable length argument list.
+            **kwargs: Arbitrary keyword arguments.
+
+        Returns:
+            ax: matplotlib ax object
+
         """
         import geopandas as gpd
         import contextily as ctx
         from shapely.geometry import Point
         import matplotlib.pyplot as plt
-        gdf = gpd.GeoDataFrame(self.dataframe, geometry = [Point(float(self.longitude),
+        gdf = gpd.GeoDataFrame(self.metadata, geometry = [Point(float(self.longitude),
                                                                  float(self.latitude))])
         gdf.crs = 'EPSG:4326'
         fig, ax = plt.subplots(1, 1)
@@ -274,15 +270,20 @@ class Lake(object):
                         date_start=None, date_end=None, *args, **kwargs):
         """
         Plot timeseries of lake water level data
-        :param how: what plotting package to use: "plotly", "seaborn" or "matplotlib"
-        :type how: str
-        :param color: color to plot timeseries with, must conform with selected package syntax
-        :type color: str
-        :param show:
-        :type show: bool
-        :param args: args to pass to matplotlib or seaborn axis
-        :param kwargs: kwargs to pass to matplotlib or seaborn axis
-        :return: matplotlib axis object, or None
+        Arguments:
+            how (str): Which method of plotting to use. Plotly (default), Matplotlib, or Seaborn.
+            color (str): Color of lineplot, cannot be passed to Plotly.
+            show (bool): If True, display figure, else return `ax` object
+            date_start (str): The beginning of the desired plotting date range supplied as %Y-%m-%d string.
+            date_end (str): The end of the desired plotting date range supplied as %Y-%m-%d string.
+            *args: Variable length argument list.
+            **kwargs: Arbitrary keyword arguments.
+
+        Returns:
+            NoneType or ax (optional): Time-series plotted through plotly in web browser. if `how` argument is
+                                        specified, returns matplotlib ax object
+
+
         """
         import matplotlib.ticker as ticker
         import plotly.io as pio
@@ -342,13 +343,3 @@ class Lake(object):
                 plt.show()
             else:
                 return ax
-
-
-if __name__ == '__main__':
-    ay = search(id_No = 377)
-    # print(ay.data)
-    # ay.plot_timeseries()
-    # ay.plot_timeseries(how='matplotlib')
-    # ay.plot_timeseries(how='seaborn')
-    ay.plot_mapview(provider = ctx.providers.Esri.WorldImagery)
-    print('done!')
